@@ -18,11 +18,11 @@ Net::Hacky::Detect::IP - Hackily try different methods of attaining local system
 
 =head1 VERSION
 
-Version 0.018
+Version 0.019
 
 =cut
 
-our $VERSION = '0.018';
+our $VERSION = '0.019';
 
 my $tools = {
     unix => {
@@ -185,28 +185,20 @@ sub scan {
         elsif ( ($type == 6 || $type == 0) && $testIP =~ m#:# && $testIP =~ m#[0-9]# && $testIP =~ m#^([a-f0-9:]+)$#) {
             # Copy $1 to $IP because it looks prettier
             my $IP = $1;
-            my $test;
+            my $error = 0;
         
-            # Can sometimes overread ipv6 IP:PORT's due to the : seperator deal with that here
             # Test its valid
-            if ($IP =~ m#^(.*):\d+$#) {
-                try {
-                    $test = IPv6::Address->new($IP);
-                };
-                $IP = $1;
-            }
-            
-            # Incase we had ports on our ipv6
-            if (!$test) {
-                try {
-                    $test = IPv6::Address->new($IP);
-                };
-            }
+            try {
+                my $test = IPv6::Address->new($IP);
+                $IP = $test->first_address;
+            } catch {
+                $error = 1;
+            };
 
             # Check we have not already dealt with this ip and its valid
             next if ($unique->{$IP});
             $unique->{$IP} = 1;
-            if (!$test || !$self->_checkIP6($IP)) { next }
+            if (!$error || !$self->_checkIP6($IP)) { next }
 
             # Push the valid ip into the return space
             push @$return,$IP;
@@ -239,6 +231,10 @@ sub checkIP {
     }
 }
 
+=head1 UNINPLEMENTED
+
+These functions are not yet working.
+
 =head2 is_public
 
 Return 1 if an address is a publically routed address.
@@ -276,24 +272,10 @@ Return 0 if it is not.
 =cut
 
 sub is_outbound {
-    my ($self,$ip) = @_;
+    my ($self,$host) = @_;
     
     my $return = 0;
 
-    if ($host =~ m#\.#) { 
-        my $sock = IO::Socket::INET->new(
-            LocalAddr   =>  $host,
-            LocalPort   =>  $port,
-            Proto       =>  'tcp',
-            ReuseAddr   =>  1
-        ) or $fail = 0;
-    } 
-    elsif ($host =~ m#:#) {
-        return $self->_checkIP6($host);
-    }
-    else { 
-        warn "$host does not look like an IPv6 nor IPv4, ignored.";
-    }
 
     return $return;
 }
